@@ -74,6 +74,9 @@ ROUTER_INTERFACE_OWNERS_SNAT = (DEVICE_OWNER_ROUTER_INTF,
                                 DEVICE_OWNER_HA_REPLICATED_INT,
                                 DEVICE_OWNER_DVR_INTERFACE,
                                 DEVICE_OWNER_ROUTER_SNAT)
+
+DEVICE_ID_RESERVED_DHCP_PORT = 'reserved_dhcp_port'
+
 FLOATINGIP_KEY = '_floatingips'
 INTERFACE_KEY = '_interfaces'
 HA_INTERFACE_KEY = '_ha_interface'
@@ -113,7 +116,9 @@ L3_AGENT_MODE_DVR = 'dvr'
 L3_AGENT_MODE_DVR_SNAT = 'dvr_snat'
 L3_AGENT_MODE_LEGACY = 'legacy'
 L3_AGENT_MODE = 'agent_mode'
+L3_AGENT_MODE_DVR_NO_EXTERNAL = 'dvr_no_external'
 
+DVR_SNAT_BOUND = 'dvr_snat_bound'
 PORT_BINDING_EXT_ALIAS = 'binding'
 L3_AGENT_SCHEDULER_EXT_ALIAS = 'l3_agent_scheduler'
 DHCP_AGENT_SCHEDULER_EXT_ALIAS = 'dhcp_agent_scheduler'
@@ -130,6 +135,7 @@ PROTO_NAME_ESP = 'esp'
 PROTO_NAME_GRE = 'gre'
 PROTO_NAME_ICMP = 'icmp'
 PROTO_NAME_IGMP = 'igmp'
+PROTO_NAME_IPIP = 'ipip'
 PROTO_NAME_IPV6_ENCAP = 'ipv6-encap'
 PROTO_NAME_IPV6_FRAG = 'ipv6-frag'
 PROTO_NAME_IPV6_ICMP = 'ipv6-icmp'
@@ -155,6 +161,7 @@ PROTO_NUM_ESP = 50
 PROTO_NUM_GRE = 47
 PROTO_NUM_ICMP = 1
 PROTO_NUM_IGMP = 2
+PROTO_NUM_IPIP = 4
 PROTO_NUM_IPV6_ENCAP = 41
 PROTO_NUM_IPV6_FRAG = 44
 PROTO_NUM_IPV6_ICMP = 58
@@ -177,6 +184,7 @@ IP_PROTOCOL_MAP = {PROTO_NAME_AH: PROTO_NUM_AH,
                    PROTO_NAME_GRE: PROTO_NUM_GRE,
                    PROTO_NAME_ICMP: PROTO_NUM_ICMP,
                    PROTO_NAME_IGMP: PROTO_NUM_IGMP,
+                   PROTO_NAME_IPIP: PROTO_NUM_IPIP,
                    PROTO_NAME_IPV6_ENCAP: PROTO_NUM_IPV6_ENCAP,
                    PROTO_NAME_IPV6_FRAG: PROTO_NUM_IPV6_FRAG,
                    PROTO_NAME_IPV6_ICMP: PROTO_NUM_IPV6_ICMP,
@@ -194,6 +202,21 @@ IP_PROTOCOL_MAP = {PROTO_NAME_AH: PROTO_NUM_AH,
                    PROTO_NAME_UDPLITE: PROTO_NUM_UDPLITE,
                    PROTO_NAME_VRRP: PROTO_NUM_VRRP}
 
+# Note that this differs from IP_PROTOCOL_MAP because iptables refers to IPv6
+# ICMP as 'icmp6' whereas it is 'ipv6-icmp' in IP_PROTOCOL_MAP.
+IPTABLES_PROTOCOL_MAP = {PROTO_NAME_DCCP: 'dccp',
+                         PROTO_NAME_ICMP: 'icmp',
+                         PROTO_NAME_IPV6_ICMP: 'icmp6',
+                         PROTO_NAME_SCTP: 'sctp',
+                         PROTO_NAME_TCP: 'tcp',
+                         PROTO_NAME_UDP: 'udp'}
+
+# IP header length
+IP_HEADER_LENGTH = {
+    4: 20,
+    6: 40,
+}
+
 # ICMPv6 types:
 # Destination Unreachable (1)
 ICMPV6_TYPE_DEST_UNREACH = 1
@@ -251,6 +274,62 @@ DHCPV6_STATELESS = 'dhcpv6-stateless'
 IPV6_SLAAC = 'slaac'
 IPV6_MODES = [DHCPV6_STATEFUL, DHCPV6_STATELESS, IPV6_SLAAC]
 
+ACTIVE_PENDING_STATUSES = (
+    ACTIVE,
+    PENDING_CREATE,
+    PENDING_UPDATE
+)
+
+# Network Type constants
+TYPE_FLAT = 'flat'
+TYPE_GENEVE = 'geneve'
+TYPE_GRE = 'gre'
+TYPE_LOCAL = 'local'
+TYPE_VXLAN = 'vxlan'
+TYPE_VLAN = 'vlan'
+TYPE_NONE = 'none'
+
+# Values for network_type
+
+# For VLAN Network
+MIN_VLAN_TAG = 1
+MAX_VLAN_TAG = 4094
+
+# For Geneve Tunnel
+MIN_GENEVE_VNI = 1
+MAX_GENEVE_VNI = 2 ** 24 - 1
+
+# For GRE Tunnel
+MIN_GRE_ID = 1
+MAX_GRE_ID = 2 ** 32 - 1
+
+# For VXLAN Tunnel
+MIN_VXLAN_VNI = 1
+MAX_VXLAN_VNI = 2 ** 24 - 1
+VXLAN_UDP_PORT = 4789
+
+# Overlay (tunnel) protocol overhead
+GENEVE_ENCAP_MIN_OVERHEAD = 30
+GRE_ENCAP_OVERHEAD = 22
+VXLAN_ENCAP_OVERHEAD = 30
+
+# For DNS extension
+DNS_DOMAIN_DEFAULT = 'openstacklocal.'
+DNS_LABEL_MAX_LEN = 63
+DNS_LABEL_REGEX = "^[a-z0-9-]{1,%d}$" % DNS_LABEL_MAX_LEN
+
+# max value for TCP, UDP, SCTP ports
+PORT_MAX = 2**16 - 1
+
+VALID_DSCP_MARKS = [0, 8, 10, 12, 14, 16, 18, 20, 22, 24, 26, 28, 30, 32, 34,
+                    36, 38, 40, 46, 48, 56]
+
+INGRESS_DIRECTION = 'ingress'
+EGRESS_DIRECTION = 'egress'
+VALID_DIRECTIONS = (INGRESS_DIRECTION, EGRESS_DIRECTION)
+
+PROVISIONAL_IPV6_PD_PREFIX = '::/64'
+
 
 class Sentinel(object):
     """A constant object that does not change even when copied."""
@@ -269,11 +348,15 @@ class Sentinel(object):
 
 ATTR_NOT_SPECIFIED = Sentinel()
 
+DICT_POPULATE_DEFAULTS = 'dict_populate_defaults'
+
 HEX_ELEM = '[0-9A-Fa-f]'
 UUID_PATTERN = '-'.join([HEX_ELEM + '{8}', HEX_ELEM + '{4}',
                          HEX_ELEM + '{4}', HEX_ELEM + '{4}',
                          HEX_ELEM + '{12}'])
 
+SHARED = 'shared'
+
 
 ##########################
 # Device related constants
