@@ -23,3 +23,5 @@ QOS = "QOS"
 CORE = 'CORE'
 L3 = 'L3_ROUTER_NAT'
 LOG_API = "LOGGING"
+PORTFORWARDING = "PORTFORWARDING"
+FLOATINGIPPOOL = "FLOATINGIPPOOL"
